import { PublicKey } from '@solana/web3.js';
import { CypherClient } from '../client';
import { CypherAccountState, StateUpdateHandler } from '../types';
import { I80F48 } from '@blockworks-foundation/mango-client';
import { Pool } from './pool';
import { FuturesMarketViewer, PerpMarketViewer } from '../viewers';
export declare class CypherAccount {
    readonly client: CypherClient;
    readonly address: PublicKey;
    state: CypherAccountState;
    private _onStateUpdate?;
    constructor(client: CypherClient, address: PublicKey, state: CypherAccountState, _onStateUpdate?: StateUpdateHandler<CypherAccountState>);
    static create(client: CypherClient, clearing: PublicKey, authority: PublicKey, accountNumber?: number): Promise<{
        account: PublicKey;
        ixs: import("@solana/web3.js").TransactionInstruction[];
        signers: any[];
    }>;
    static load(client: CypherClient, address: PublicKey, onStateUpdateHandler?: StateUpdateHandler<CypherAccountState>): Promise<CypherAccount>;
    getSubAccounts(): PublicKey[];
    getCRatio(): {
        assetsValue: I80F48;
        liabilitiesValue: I80F48;
        cRatio: I80F48;
    };
    subscribe(): void;
    unsubscribe(): Promise<void>;
    getSpotOpenOrdersAddress(dexMarket: PublicKey, subAccount: PublicKey): PublicKey;
    getDerivativesOpenOrdersAddress(market: PublicKey): PublicKey;
    hasSpotOpenOrders(dexMarket: PublicKey, subAccount: PublicKey): Promise<boolean>;
    hasDerivativeOpenOrders(market: PublicKey): Promise<boolean>;
    getSpotMarketOrders(pool: Pool): Promise<import("@project-serum/serum/lib/market").Order[]>;
    getDerivativeMarketOrders(market: FuturesMarketViewer | PerpMarketViewer): Promise<import("./ordersAccount").Order[]>;
    getAssociatedTokenAddress(tokenMint: PublicKey): Promise<PublicKey>;
}
