"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Clearing = void 0;
const web3_js_1 = require("@solana/web3.js");
const pda_1 = require("../utils/pda");
class Clearing {
    constructor(address, state) {
        this.address = address;
        this.state = state;
    }
    static async createPublicClearing(client, authority, args) {
        const [clearing, bump] = (0, pda_1.derivePublicClearingAddress)(client.cypherPID);
        args.bump = bump;
        const ix = await client.methods
            .createPublicClearing({
            ...args,
            clearingType: args.clearingType
        })
            .accountsStrict({
            clearing,
            authority,
            payer: client.walletPubkey,
            systemProgram: web3_js_1.SystemProgram.programId
        })
            .instruction();
        return {
            clearing,
            ixs: [ix],
            signers: []
        };
    }
    static async createPrivateClearing(client, authority, args) {
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
        const [publicClearing, publicClearingBump] = (0, pda_1.derivePublicClearingAddress)(client.cypherPID);
        const [privateClearing, privateClearingBump] = (0, pda_1.derivePrivateClearingAddress)(args.clearingNumber, client.cypherPID);
        args.bump = privateClearingBump;
        const ix = await client.methods
            .createPrivateClearing({
            ...args,
            clearingType: args.clearingType
        })
            .accountsStrict({
            clearing: publicClearing,
            privateClearing: privateClearing,
            authority,
            payer: client.walletPubkey,
            systemProgram: web3_js_1.SystemProgram.programId
        })
            .instruction();
        return {
            privateClearing,
            ixs: [ix],
            signers: []
        };
    }
    static async load(client, address) {
        const state = (await client.accounts.clearing.fetch(address));
        return new Clearing(address, state);
    }
}
exports.Clearing = Clearing;
//# sourceMappingURL=clearing.js.map