"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OracleProducts = void 0;
const web3_js_1 = require("@solana/web3.js");
const pda_1 = require("../utils/pda");
class OracleProducts {
    constructor(address, state) {
        this.address = address;
        this.state = state;
    }
    static async create(client, cacheAccount, authority, oracleAddrs, args) {
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
        const [oracleProductsAddress, bump] = (0, pda_1.deriveOracleProductsAddress)(args.symbol, client.cypherPID);
        const ix = await client.methods
            .createOracleProducts({
            ...args,
            productsType: args.productsType
        })
            .accountsStrict({
            cacheAccount,
            oracleProducts: oracleProductsAddress,
            payer: authority,
            authority,
            systemProgram: web3_js_1.SystemProgram.programId
        })
            .remainingAccounts(oracleAddrs.map((product) => ({
            pubkey: product,
            isSigner: false,
            isWritable: false
        })))
            .instruction();
        return {
            oracleProducts: oracleProductsAddress,
            ixs: [ix],
            signers: []
        };
    }
    static async load(client, address) {
        const state = (await client.accounts.oracleProducts.fetch(address));
        return new OracleProducts(address, state);
    }
}
exports.OracleProducts = OracleProducts;
//# sourceMappingURL=oracleProducts.js.map