import { PublicKey } from '@solana/web3.js';
import { Market } from '@project-serum/serum';
import { CypherClient } from '../client';
import type { CreatePoolArgs, PoolState, StateUpdateHandler } from '../types';
import { I80F48 } from '@blockworks-foundation/mango-client';
export declare class Pool {
    readonly client: CypherClient;
    readonly address: PublicKey;
    state: PoolState;
    readonly market?: Market;
    private _onStateUpdate?;
    constructor(client: CypherClient, address: PublicKey, state: PoolState, market?: Market, _onStateUpdate?: StateUpdateHandler<PoolState>);
    static create(client: CypherClient, clearing: PublicKey, cacheAccount: PublicKey, tokenMint: PublicKey, authority: PublicKey, dexMarket: PublicKey, oracleProducts: PublicKey, args: CreatePoolArgs): Promise<PublicKey>;
    static load(client: CypherClient, address: PublicKey, onStateUpdateHandler?: StateUpdateHandler<PoolState>): Promise<Pool>;
    static loadAll(client: CypherClient): Promise<Pool[]>;
    get dexMarket(): PublicKey;
    get maxApr(): I80F48;
    get optimalApr(): I80F48;
    get optimalUtil(): I80F48;
    get deposits(): I80F48;
    get borrows(): I80F48;
    get totalDeposits(): I80F48;
    get totalBorrows(): I80F48;
    get depositIndex(): I80F48;
    get borrowIndex(): I80F48;
    get depositRate(): I80F48;
    get borrowRate(): I80F48;
    subscribe(): void;
    unsubscribe(): Promise<void>;
}
