"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PoolNode = void 0;
const serum_1 = require("@project-serum/serum");
const mango_client_1 = require("@blockworks-foundation/mango-client");
class PoolNode {
    constructor(client, address, state, market, _onStateUpdate) {
        this.client = client;
        this.address = address;
        this.state = state;
        this.market = market;
        this._onStateUpdate = _onStateUpdate;
        _onStateUpdate && this.subscribe();
    }
    static async load(client, address, onStateUpdateHandler) {
        const state = (await client.accounts.poolNode.fetchNullable(address));
        return new PoolNode(client, address, state, null, onStateUpdateHandler);
    }
    static async loadAll(client) {
        const pools = [];
        const queryResult = await client.accounts.pool.all();
        for (const result of queryResult) {
            const market = await serum_1.Market.load(client.connection, result.account.dexMarket, {}, client.dexPID);
            pools.push(new PoolNode(client, result.publicKey, result.account, market));
        }
        return pools;
    }
    get deposits() {
        return new mango_client_1.I80F48(this.state.deposits);
    }
    get borrows() {
        return new mango_client_1.I80F48(this.state.borrows);
    }
    subscribe() {
        this.client.accounts.poolNode
            .subscribe(this.address)
            .on('change', (state) => {
            this.state = state;
            // todo: check if dexMarkets need to be reloaded.(market listing/delisting)
            if (this._onStateUpdate) {
                this._onStateUpdate(this.state);
            }
        });
    }
    async unsubscribe() {
        await this.client.accounts.poolNode.unsubscribe(this.address);
    }
}
exports.PoolNode = PoolNode;
//# sourceMappingURL=poolNode.js.map