"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.transactionErrorToErrorName = exports.transactionErrorToString = exports.getErrNameAndMsg = exports.getErrName = exports.getCustomProgramErrorCode = void 0;
const cypher_json_1 = __importDefault(require("../generated/idl/cypher.json"));
const getCustomProgramErrorCode = (errMessage) => {
    const idx = errMessage.indexOf('custom program error:');
    if (idx == -1) {
        return [false, 'May not be a custom program error'];
    }
    else {
        return [
            true,
            `${parseInt(errMessage.substring(idx + 22, idx + 28).replace(' ', ''), 16)}`
        ];
    }
};
exports.getCustomProgramErrorCode = getCustomProgramErrorCode;
const getErrName = (errCode) => {
    const code = Number(errCode);
    const customProgramErrors = cypher_json_1.default.errors;
    if (code >= 100 && code <= 5000) {
        return `This is an Anchor program error code ${code}. Please check here: https://github.com/project-serum/anchor/blob/master/lang/src/error.rs`;
    }
    for (let i = 0; i < customProgramErrors.length; i++) {
        const err = customProgramErrors[i];
        if (err.code === code) {
            return err.name;
        }
    }
    return `No matching error code description or translation for ${errCode}`;
};
exports.getErrName = getErrName;
const getErrNameAndMsg = (errCode) => {
    const code = Number(errCode);
    const customProgramErrors = cypher_json_1.default.errors;
    if (code >= 100 && code <= 5000) {
        return `This is an Anchor program error code ${code}. Please check here: https://github.com/project-serum/anchor/blob/master/lang/src/error.rs`;
    }
    for (let i = 0; i < customProgramErrors.length; i++) {
        const err = customProgramErrors[i];
        if (err.code === code) {
            return `\n\nCustom Program Error Code: ${errCode} \n- ${err.name} \n- ${err.msg}`;
        }
    }
    return `No matching error code description or translation for ${errCode}`;
};
exports.getErrNameAndMsg = getErrNameAndMsg;
// eslint-disable-next-line
const transactionErrorToString = (error) => {
    if (error.code) {
        return `Code ${error.code}: ${error.msg}\n${error.logs}\n${error.stack}`;
    }
    else {
        return `${error} ${(0, exports.getErrNameAndMsg)(Number((0, exports.getCustomProgramErrorCode)(JSON.stringify(error))[1]))}`;
    }
};
exports.transactionErrorToString = transactionErrorToString;
// eslint-disable-next-line
const transactionErrorToErrorName = (error) => {
    if (error.code) {
        return (0, exports.getErrName)(error.code);
    }
    else {
        return (0, exports.getErrName)(Number((0, exports.getCustomProgramErrorCode)(JSON.stringify(error))[1]));
    }
};
exports.transactionErrorToErrorName = transactionErrorToErrorName;
//# sourceMappingURL=error.js.map