"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getArgsInLots = exports.createObjectWithKeyFromString = exports.getDefaultPriorityFeeIxs = exports.decodeUint8ArrayToStr = exports.encodeStrToUint8Array = void 0;
const web3_js_1 = require("@solana/web3.js");
const utils_1 = require("../utils");
const constants_1 = require("../constants");
const anchor_1 = require("@project-serum/anchor");
const shared_1 = require("../constants/shared");
/**
 * String encoding for Pools and Market names.
 * @param str The name.
 * @returns The encoded value.
 */
const encodeStrToUint8Array = (str) => {
    const encoder = new TextEncoder();
    const empty = Array(32).fill(0);
    const encodedArr = Array.from(encoder.encode(str));
    return empty.map((_, i) => encodedArr[i] || 0);
};
exports.encodeStrToUint8Array = encodeStrToUint8Array;
const decodeUint8ArrayToStr = (numArr) => {
    const decoder = new TextDecoder();
    return decoder.decode(new Uint8Array(numArr)).replaceAll('\x00', '');
};
exports.decodeUint8ArrayToStr = decodeUint8ArrayToStr;
const getDefaultPriorityFeeIxs = () => ({
    modifyComputeUnits: web3_js_1.ComputeBudgetProgram.setComputeUnitLimit({
        units: 1000000
    }),
    addPriorityFee: web3_js_1.ComputeBudgetProgram.setComputeUnitPrice({
        microLamports: 1
    })
});
exports.getDefaultPriorityFeeIxs = getDefaultPriorityFeeIxs;
const createObjectWithKeyFromString = (key) => ({ [key]: {} });
exports.createObjectWithKeyFromString = createObjectWithKeyFromString;
const getArgsInLots = ({ clearing, baseLotSize, quoteLotSize, price, account, decimals, size }) => {
    const limitPrice = (0, utils_1.uiToSplAmount)(price, shared_1.QUOTE_TOKEN_DECIMALS);
    const decimalFactor = new anchor_1.BN(Math.pow(10, decimals));
    const feeTier = account.state.feeTier;
    const feeBps = new anchor_1.BN(clearing.state.feeTiers[feeTier - 1].takerBps + 1);
    const bips = new anchor_1.BN(constants_1.BPS_100_PERCENT);
    const priceInLots = limitPrice
        .mul(baseLotSize)
        .div(decimalFactor.mul(quoteLotSize));
    const sizeInLots = new anchor_1.BN((size * decimalFactor.toNumber()) / baseLotSize.toNumber());
    const quoteWoFee = priceInLots.mul(sizeInLots).mul(quoteLotSize);
    const quoteInLots = quoteWoFee.mul(bips.add(feeBps)).div(bips);
    return { priceInLots, sizeInLots, quoteInLots };
};
exports.getArgsInLots = getArgsInLots;
//# sourceMappingURL=ixs.js.map